# pyTMDL

## Install

```bash
$ pip install pytmdl
$ poetry add pytmdl
```

## References

- TMDL project example: https://github.com/mthierba/tmdl-example/tree/main
- `lkml` parser: https://github.com/joshtemple/lkml
- `pyYAML` parser for load/dump method: https://github.com/yaml/pyyaml/tree/main
- `pydantic`: https://docs.pydantic.dev/latest/concepts/models/
- Microsoft.AnalysisServices Namespace: https://learn.microsoft.com/en-us/dotnet/api/microsoft.analysisservices?view=analysisservices-dotnet
- Microsoft.AnalysisServices.Tabular Namepsace: https://learn.microsoft.com/en-us/dotnet/api/microsoft.analysisservices.tabular?view=analysisservices-dotnet
